@@ -1,6 +1,6 @@
 package ETL::Yertl::Command::ygrok;
 # ABSTRACT: Parse lines of text into documents
-$ETL::Yertl::Command::ygrok::VERSION = '0.023';
+$ETL::Yertl::Command::ygrok::VERSION = '0.024';
 use ETL::Yertl;
 use Getopt::Long qw( GetOptionsFromArray );
 use ETL::Yertl::Format::yaml;
@@ -73,11 +73,14 @@ our %PATTERNS = (
         #       No STAT field
         # -- OpenBSD
         #       STAT field
+        # -- RHEL 5
+        #       tty can contain /
+        #       Seconds time optional
         PS => join( " +",
             ' *%{INT:pid}',
-            '(?<tty>[\w?]+)',
+            '(?<tty>[\w?/]+)',
             '(?<status>(?:[\w+]+))?',
-            '(?<time>\d+:\d+[:.]\d+)',
+            '(?<time>\d+:\d+(?:[:.]\d+)?)',
             '%{DATA:command}',
         ),
 
@@ -89,19 +92,19 @@ our %PATTERNS = (
             '%{NUM:mem}',
             '%{INT:vsz}',
             '%{INT:rss}',
-            '(?<tty>[\w?]+)',
+            '(?<tty>[\w?/]+)',
             '(?<status>(?:[\w+]+))?',
             '(?<started>[\w:]+)',
-            '(?<time>\d+:\d+[:.]\d+)',
+            '(?<time>\d+:\d+(?:[:.]\d+)?)',
             '%{DATA:command}',
         ),
 
         # Max OSX and OpenBSD are the same
         PSX => join ( " +",
             ' *%{INT:pid}',
-            '(?<tty>[\w?]+)',
+            '(?<tty>[\w?/]+)',
             '(?<status>(?:[\w+]+))',
-            '(?<time>\d+:\d+[:.]\d+)',
+            '(?<time>\d+:\d+(?:[:.]\d+)?)',
             '%{DATA:command}',
         ),
     },
@@ -281,7 +284,7 @@ ETL::Yertl::Command::ygrok - Parse lines of text into documents
 
 =head1 VERSION
 
-version 0.023
+version 0.024
 
 =head1 AUTHOR
 
